json

package module
v0.0.0-...-85ccbf3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 18, 2023 License: MIT Imports: 1 Imported by: 0

README

go-json

json parser

[!WARNING] This is a repository to learn how to write the json parser and do not use production.

refs

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewParser

func NewParser(input string) *parser.Parser

Types

This section is empty.

Directories

Path Synopsis

Jump to